Struct holding a list of processor specifications for a pipeline.
Build with Feline.Pipeline.new/1 and run with Feline.Pipeline.Task.
Struct holding a list of processor specifications for a pipeline.
Build with Feline.Pipeline.new/1 and run with Feline.Pipeline.Task.