Feline.Transports.WebSocket.Handler (feline v0.1.0-rc.1)

Copy Markdown View Source

WebSock handler that receives binary audio and text messages from clients and queues them as frames into the pipeline.